@@ -31,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.41';
+our $VERSION = '2.42';
 
 =head1 SYNOPSIS
 
@@ -782,14 +782,14 @@ sub parse_file_slurm{
         }
         next if $line =~ m/^#/;
 
-        #$DB::single=2;
+        $DB::single=2;
 
         #Do a sanity check for nohup
         if($line =~ m/^nohup/){
             die print "You cannot submit jobs to the queue using nohup! Please remove nohup and try again.\n";
         }
 
-        if( 0 == $self->cmd_counter % ($self->commands_per_node + 1) && $self->batch ){
+        if( $self->cmd_counter > 0 && 0 == $self->cmd_counter % ($self->commands_per_node + 1) && $self->batch ){
             #Run this batch and start the next
             $DB::single=2;
             $self->work;
@@ -800,6 +800,7 @@ sub parse_file_slurm{
             $self->add_cmd($line);
             $self->add_batch($line);
             if($line =~ m/\\$/){
+                $DB::single=2;
                 next;
             }
             else{
